# pyESI: Ensemble Spatial Interpolation with Python
[![PyPI Latest Release](https://img.shields.io/pypi/v/pyESI.svg)](https://pypi.org/project/pyESI/)

## What is it?

**pyESI** is a Python package that provides an implementation for Ensemble
Spatial Interpolation method. It aims to be an easy-to-use alternative to 
traditional spatial interpolators in Python.

## Where to get it
The source code is currently hosted on GitHub at:
https://github.com/alges/pyESI

Binary installers for the latest released version are available at the [Python
Package Index (PyPI)](https://pypi.org/project/pyESI).

# PyPI
```bash
pip install pyESI
```

# Dependencies
- [NumPy - Powerful n-dimensional arrays and numerical computing tools](https://www.numpy.org)
- [pandas - Fast, powerful, flexible and easy to use open source data analysis and manipulation tool](https://pandas.pydata.org)

## License
[MIT](LICENSE)

# Acknowledge
Please cite the following paper when publishing work relating this code:

    @inproceedings{egana2021,
      Author = {},
      Title = {},
      Booktitle = {},
      Series = {},
      Year = {2021},
      doi = {},
      pages = {1--12}
    }
